@@ -1,6 +1,6 @@
 /*
  *  CDEmu daemon: main header
- *  Copyright (C) 2006-2014 Rok Mandeljc
+ *  Copyright (C) 2006-2026 Rok Mandeljc
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,9 +17,7 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
-#ifndef __CDEMU_H__
-#define __CDEMU_H__
+#pragma once
 
 #include "config.h"
 
@@ -57,4 +55,9 @@
 #include "daemon.h"
 #include "device.h"
 
-#endif /* __CDEMU_H__ */
+/* G_SOURCE_FUNC() macro is available since GLib2 2.58. As long as we
+ * nominally provide support for building with older versions, provide
+ * an equivalent macro definition. */
+#if !defined(G_SOURCE_FUNC)
+#define G_SOURCE_FUNC(f) ((GSourceFunc) (void (*)(void)) (f))
+#endif
