@@ -1,6 +1,6 @@
 /*
  *  CDEmu daemon: daemon - D-Bus
- *  Copyright (C) 2012-2014 Rok Mandeljc
+ *  Copyright (C) 2012-2026 Rok Mandeljc
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,105 @@
 #define DBUS_ERROR_CDEMU "net.sf.cdemu.CDEmuDaemon.errorDaemon"
 #define DBUS_ERROR_LIBMIRAGE "net.sf.cdemu.CDEmuDaemon.errorMirage"
 
-static const gchar introspection_xml[];
+
+/**********************************************************************\
+ *                   Embedded introspection data                      *
+\**********************************************************************/
+static const gchar introspection_xml[] =
+    "<node>"
+    "    <interface name='" CDEMU_DAEMON_DBUS_NAME "'>"
+    "        <!-- Information-related methods -->"
+    "        <method name='GetDaemonVersion'>"
+    "            <arg name='version' type='s' direction='out'/>"
+    "        </method>"
+    "        <method name='GetLibraryVersion'>"
+    "            <arg name='version' type='s' direction='out'/>"
+    "        </method>"
+    "        <method name='GetDaemonInterfaceVersion'>"
+    "            <arg name='version' type='i' direction='out'/>"
+    "        </method>"
+    "        <method name='GetDaemonInterfaceVersion2'>"
+    "            <arg name='major' type='i' direction='out'/>"
+    "            <arg name='minor' type='i' direction='out'/>"
+    "        </method>"
+    "        <method name='EnumDaemonDebugMasks'>"
+    "            <arg name='masks' type='a(si)' direction='out'/>"
+    "        </method>"
+    "        <method name='EnumLibraryDebugMasks'>"
+    "            <arg name='masks' type='a(si)' direction='out'/>"
+    "        </method>"
+    "        <method name='EnumSupportedParsers'>"
+    "            <arg name='parsers' type='a(ssa(ss))' direction='out'/>"
+    "        </method>"
+    "        <method name='EnumSupportedWriters'>"
+    "            <arg name='writers' type='a(ss)' direction='out'/>"
+    "        </method>"
+    "        <method name='EnumSupportedFilterStreams'>"
+    "            <arg name='filter_streams' type='a(ssba(ss))' direction='out'/>"
+    "        </method>"
+    "        <method name='EnumWriterParameters'>"
+    "            <arg name='writer_id' type='s' direction='in'/>"
+    "            <arg name='parameter_sheet' type='a(sssvas)' direction='out'/>"
+    "        </method>"
+
+    "        <!-- Device control methods -->"
+    "        <method name='GetNumberOfDevices'>"
+    "            <arg name='number_of_devices' type='i' direction='out'/>"
+    "        </method>"
+    "        <method name='DeviceGetMapping'>"
+    "            <arg name='device_number' type='i' direction='in'/>"
+    "            <arg name='sr_device' type='s' direction='out'/>"
+    "            <arg name='sg_device' type='s' direction='out'/>"
+    "        </method>"
+    "        <method name='DeviceGetStatus'>"
+    "            <arg name='device_number' type='i' direction='in'/>"
+    "            <arg name='loaded' type='b' direction='out'/>"
+    "            <arg name='filenames' type='as' direction='out'/>"
+    "        </method>"
+    "        <method name='DeviceLoad'>"
+    "            <arg name='device_number' type='i' direction='in'/>"
+    "            <arg name='filenames' type='as' direction='in'/>"
+    "            <arg name='parameters' type='a{sv}' direction='in'/>"
+    "        </method>"
+    "        <method name='DeviceCreateBlank'>"
+    "            <arg name='device_number' type='i' direction='in'/>"
+    "            <arg name='filename' type='s' direction='in'/>"
+    "            <arg name='parameters' type='a{sv}' direction='in'/>"
+    "        </method>"
+    "        <method name='DeviceUnload'>"
+    "            <arg name='device_number' type='i' direction='in'/>"
+    "        </method>"
+    "        <method name='DeviceGetOption'>"
+    "            <arg name='device_number' type='i' direction='in'/>"
+    "            <arg name='option_name' type='s' direction='in'/>"
+    "            <arg name='option_values' type='v' direction='out'/>"
+    "        </method>"
+    "        <method name='DeviceSetOption'>"
+    "            <arg name='device_number' type='i' direction='in'/>"
+    "            <arg name='option_name' type='s' direction='in'/>"
+    "            <arg name='option_values' type='v' direction='in'/>"
+    "        </method>"
+
+    "        <!-- Device management methods -->"
+    "        <method name='AddDevice' />"
+    "        <method name='RemoveDevice' />"
+
+    "        <!-- Notification signals -->"
+    "        <signal name='DeviceStatusChanged'>"
+    "            <arg name='device_number' type='i' direction='out'/>"
+    "        </signal>"
+    "        <signal name='DeviceOptionChanged'>"
+    "            <arg name='device_number' type='i' direction='out'/>"
+    "            <arg name='option' type='s' direction='out'/>"
+    "        </signal>"
+    "        <signal name='DeviceMappingReady'>"
+    "            <arg name='device_number' type='i' direction='out'/>"
+    "        </signal>"
+    "        <signal name='DeviceAdded' />"
+    "        <signal name='DeviceRemoved' />"
+    "    </interface>"
+    "</node>"
+;
 
 
 /**********************************************************************\
@@ -303,12 +401,13 @@ static void cdemu_daemon_dbus_handle_method_call (GDBusConnection *connection G_
     } else if (!g_strcmp0(method_name, "EnumDaemonDebugMasks")) {
         /* *** EnumDaemonDebugMasks *** */
         static const MirageDebugMaskInfo dbg_masks[] = {
-            { "DAEMON_DEBUG_DEVICE", DAEMON_DEBUG_DEVICE },
-            { "DAEMON_DEBUG_MMC", DAEMON_DEBUG_MMC },
-            { "DAEMON_DEBUG_DELAY", DAEMON_DEBUG_DELAY },
-            { "DAEMON_DEBUG_AUDIOPLAY", DAEMON_DEBUG_AUDIOPLAY },
-            { "DAEMON_DEBUG_KERNEL_IO", DAEMON_DEBUG_KERNEL_IO },
-            { "DAEMON_DEBUG_RECORDING", DAEMON_DEBUG_RECORDING },
+            {"DAEMON_DEBUG_DEVICE", DAEMON_DEBUG_DEVICE},
+            {"DAEMON_DEBUG_MMC", DAEMON_DEBUG_MMC},
+            {"DAEMON_DEBUG_DELAY", DAEMON_DEBUG_DELAY},
+            {"DAEMON_DEBUG_AUDIOPLAY", DAEMON_DEBUG_AUDIOPLAY},
+            {"DAEMON_DEBUG_KERNEL_IO", DAEMON_DEBUG_KERNEL_IO},
+            {"DAEMON_DEBUG_RECORDING", DAEMON_DEBUG_RECORDING},
+            {"DAEMON_DEBUG_SLEEP_HANDLER", DAEMON_DEBUG_SLEEP_HANDLER},
         };
 
         GVariantBuilder *masks = encode_masks(dbg_masks, G_N_ELEMENTS(dbg_masks));
@@ -401,7 +500,7 @@ static const GDBusInterfaceVTable dbus_interface_vtable = {
     (GDBusInterfaceMethodCallFunc)cdemu_daemon_dbus_handle_method_call,
     NULL,
     NULL,
-    { NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL }
+    {NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL}
 };
 
 
@@ -434,8 +533,9 @@ static void on_bus_acquired (GDBusConnection *connection, const gchar *name G_GN
 }
 
 
-static void on_name_lost (GDBusConnection *connection G_GNUC_UNUSED, const gchar *name G_GNUC_UNUSED, CdemuDaemon *self)
+static void on_name_lost (GDBusConnection *connection G_GNUC_UNUSED, const gchar *name, CdemuDaemon *self)
 {
+    CDEMU_DEBUG(self, DAEMON_DEBUG_WARNING, "%s: failed to register name %s on %s bus!\n", __debug__, name, self->priv->bus_type == G_BUS_TYPE_SYSTEM ? "system" : "session");
     cdemu_daemon_stop_daemon(self);
 }
 
@@ -524,149 +624,85 @@ void cdemu_daemon_dbus_cleanup (CdemuDaemon *self)
 \**********************************************************************/
 void cdemu_daemon_dbus_emit_device_status_changed (CdemuDaemon *self, gint number)
 {
-    if (self->priv->connection) {
-        g_dbus_connection_emit_signal(self->priv->connection, NULL,
-            "/Daemon", CDEMU_DAEMON_DBUS_NAME,
-            "DeviceStatusChanged", g_variant_new("(i)", number),
-            NULL);
+    if (!self->priv->connection) {
+        return;
     }
+
+    g_dbus_connection_emit_signal(
+        self->priv->connection,
+        NULL,
+        "/Daemon",
+        CDEMU_DAEMON_DBUS_NAME,
+        "DeviceStatusChanged",
+        g_variant_new("(i)", number),
+        NULL
+    );
 }
 
 void cdemu_daemon_dbus_emit_device_option_changed (CdemuDaemon *self, gint number, const gchar *option)
 {
-    if (self->priv->connection) {
-        g_dbus_connection_emit_signal(self->priv->connection, NULL,
-            "/Daemon", CDEMU_DAEMON_DBUS_NAME,
-            "DeviceOptionChanged", g_variant_new("(is)", number, option),
-            NULL);
+    if (!self->priv->connection) {
+        return;
     }
+
+    g_dbus_connection_emit_signal(
+        self->priv->connection,
+        NULL,
+        "/Daemon",
+        CDEMU_DAEMON_DBUS_NAME,
+        "DeviceOptionChanged",
+        g_variant_new("(is)", number, option),
+        NULL
+    );
 }
 
 void cdemu_daemon_dbus_emit_device_mapping_ready (CdemuDaemon *self, gint number)
 {
-    if (self->priv->connection) {
-        g_dbus_connection_emit_signal(self->priv->connection, NULL,
-            "/Daemon", CDEMU_DAEMON_DBUS_NAME,
-            "DeviceMappingReady", g_variant_new("(i)", number),
-            NULL);
+    if (!self->priv->connection) {
+        return;
     }
+
+    g_dbus_connection_emit_signal(
+        self->priv->connection,
+        NULL,
+        "/Daemon",
+        CDEMU_DAEMON_DBUS_NAME,
+        "DeviceMappingReady",
+        g_variant_new("(i)", number),
+        NULL
+    );
 }
 
 void cdemu_daemon_dbus_emit_device_added (CdemuDaemon *self)
 {
-    if (self->priv->connection) {
-        g_dbus_connection_emit_signal(self->priv->connection, NULL,
-            "/Daemon", CDEMU_DAEMON_DBUS_NAME,
-            "DeviceAdded", NULL,
-            NULL);
+    if (!self->priv->connection) {
+        return;
     }
+
+    g_dbus_connection_emit_signal(
+        self->priv->connection,
+        NULL,
+        "/Daemon",
+        CDEMU_DAEMON_DBUS_NAME,
+        "DeviceAdded",
+        NULL,
+        NULL
+    );
 }
 
 void cdemu_daemon_dbus_emit_device_removed (CdemuDaemon *self)
 {
-    if (self->priv->connection) {
-        g_dbus_connection_emit_signal(self->priv->connection, NULL,
-            "/Daemon", CDEMU_DAEMON_DBUS_NAME,
-            "DeviceRemoved", NULL,
-            NULL);
+    if (!self->priv->connection) {
+        return;
     }
+
+    g_dbus_connection_emit_signal(
+        self->priv->connection,
+        NULL,
+        "/Daemon",
+        CDEMU_DAEMON_DBUS_NAME,
+        "DeviceRemoved",
+        NULL,
+        NULL
+    );
 }
-
-
-/**********************************************************************\
- *                   Embedded introspection data                      *
-\**********************************************************************/
-static const gchar introspection_xml[] =
-    "<node>"
-    "    <interface name='" CDEMU_DAEMON_DBUS_NAME "'>"
-    "        <!-- Information-related methods -->"
-    "        <method name='GetDaemonVersion'>"
-    "            <arg name='version' type='s' direction='out'/>"
-    "        </method>"
-    "        <method name='GetLibraryVersion'>"
-    "            <arg name='version' type='s' direction='out'/>"
-    "        </method>"
-    "        <method name='GetDaemonInterfaceVersion'>"
-    "            <arg name='version' type='i' direction='out'/>"
-    "        </method>"
-    "        <method name='GetDaemonInterfaceVersion2'>"
-    "            <arg name='major' type='i' direction='out'/>"
-    "            <arg name='minor' type='i' direction='out'/>"
-    "        </method>"
-    "        <method name='EnumDaemonDebugMasks'>"
-    "            <arg name='masks' type='a(si)' direction='out'/>"
-    "        </method>"
-    "        <method name='EnumLibraryDebugMasks'>"
-    "            <arg name='masks' type='a(si)' direction='out'/>"
-    "        </method>"
-    "        <method name='EnumSupportedParsers'>"
-    "            <arg name='parsers' type='a(ssa(ss))' direction='out'/>"
-    "        </method>"
-    "        <method name='EnumSupportedWriters'>"
-    "            <arg name='writers' type='a(ss)' direction='out'/>"
-    "        </method>"
-    "        <method name='EnumSupportedFilterStreams'>"
-    "            <arg name='filter_streams' type='a(ssba(ss))' direction='out'/>"
-    "        </method>"
-    "        <method name='EnumWriterParameters'>"
-    "            <arg name='writer_id' type='s' direction='in'/>"
-    "            <arg name='parameter_sheet' type='a(sssvas)' direction='out'/>"
-    "        </method>"
-
-    "        <!-- Device control methods -->"
-    "        <method name='GetNumberOfDevices'>"
-    "            <arg name='number_of_devices' type='i' direction='out'/>"
-    "        </method>"
-    "        <method name='DeviceGetMapping'>"
-    "            <arg name='device_number' type='i' direction='in'/>"
-    "            <arg name='sr_device' type='s' direction='out'/>"
-    "            <arg name='sg_device' type='s' direction='out'/>"
-    "        </method>"
-    "        <method name='DeviceGetStatus'>"
-    "            <arg name='device_number' type='i' direction='in'/>"
-    "            <arg name='loaded' type='b' direction='out'/>"
-    "            <arg name='filenames' type='as' direction='out'/>"
-    "        </method>"
-    "        <method name='DeviceLoad'>"
-    "            <arg name='device_number' type='i' direction='in'/>"
-    "            <arg name='filenames' type='as' direction='in'/>"
-    "            <arg name='parameters' type='a{sv}' direction='in'/>"
-    "        </method>"
-    "        <method name='DeviceCreateBlank'>"
-    "            <arg name='device_number' type='i' direction='in'/>"
-    "            <arg name='filename' type='s' direction='in'/>"
-    "            <arg name='parameters' type='a{sv}' direction='in'/>"
-    "        </method>"
-    "        <method name='DeviceUnload'>"
-    "            <arg name='device_number' type='i' direction='in'/>"
-    "        </method>"
-    "        <method name='DeviceGetOption'>"
-    "            <arg name='device_number' type='i' direction='in'/>"
-    "            <arg name='option_name' type='s' direction='in'/>"
-    "            <arg name='option_values' type='v' direction='out'/>"
-    "        </method>"
-    "        <method name='DeviceSetOption'>"
-    "            <arg name='device_number' type='i' direction='in'/>"
-    "            <arg name='option_name' type='s' direction='in'/>"
-    "            <arg name='option_values' type='v' direction='in'/>"
-    "        </method>"
-
-    "        <!-- Device management methods -->"
-    "        <method name='AddDevice' />"
-    "        <method name='RemoveDevice' />"
-
-    "        <!-- Notification signals -->"
-    "        <signal name='DeviceStatusChanged'>"
-    "            <arg name='device_number' type='i' direction='out'/>"
-    "        </signal>"
-    "        <signal name='DeviceOptionChanged'>"
-    "            <arg name='device_number' type='i' direction='out'/>"
-    "            <arg name='option' type='s' direction='out'/>"
-    "        </signal>"
-    "        <signal name='DeviceMappingReady'>"
-    "            <arg name='device_number' type='i' direction='out'/>"
-    "        </signal>"
-    "        <signal name='DeviceAdded' />"
-    "        <signal name='DeviceRemoved' />"
-    "    </interface>"
-    "</node>";
