@@ -1,6 +1,6 @@
 /*
  *  CDEmu daemon: device
- *  Copyright (C) 2006-2014 Rok Mandeljc
+ *  Copyright (C) 2006-2026 Rok Mandeljc
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,6 +23,10 @@
 #define __debug__ "Device"
 
 
+/* Object definition */
+G_DEFINE_TYPE_WITH_PRIVATE(CdemuDevice, cdemu_device, MIRAGE_TYPE_OBJECT)
+
+
 /**********************************************************************\
  *                              Device ID                             *
 \**********************************************************************/
@@ -58,8 +62,8 @@ gboolean cdemu_device_initialize (CdemuDevice *self, gint number, const gchar *a
     self->priv->device_name = g_strdup_printf("cdemu%i", number);
 
     /* NOTE: self->priv->device_serial is generated in cdemu_device_start(),
-       once the control device is opened and global device number is
-       obtained from it */
+     * once the control device is opened and global device number is
+     * obtained from it */
 
     /* Init device mutex */
     self->priv->device_mutex = g_new(GMutex, 1);
@@ -71,7 +75,7 @@ gboolean cdemu_device_initialize (CdemuDevice *self, gint number, const gchar *a
 
     /* Create mapping setup timer with 1-second granularity */
     source = g_timeout_source_new_seconds(1);
-    g_source_set_callback(source, (GSourceFunc)cdemu_device_setup_mapping, self, NULL);
+    g_source_set_callback(source, G_SOURCE_FUNC(cdemu_device_setup_mapping), self, NULL);
     g_source_attach(source, self->priv->main_context);
     g_source_unref(source);
 
@@ -321,8 +325,6 @@ gboolean cdemu_device_set_option (CdemuDevice *self, gchar *option_name, GVarian
 /**********************************************************************\
  *                             Object init                            *
 \**********************************************************************/
-G_DEFINE_TYPE_WITH_PRIVATE(CdemuDevice, cdemu_device, MIRAGE_TYPE_OBJECT)
-
 static void cdemu_device_init (CdemuDevice *self)
 {
     self->priv = cdemu_device_get_instance_private(self);
@@ -402,7 +404,7 @@ static void cdemu_device_dispose (GObject *gobject)
     }
 
     /* Chain up to the parent class */
-    return G_OBJECT_CLASS(cdemu_device_parent_class)->dispose(gobject);
+    G_OBJECT_CLASS(cdemu_device_parent_class)->dispose(gobject);
 }
 
 static void cdemu_device_finalize (GObject *gobject)
@@ -447,7 +449,7 @@ static void cdemu_device_finalize (GObject *gobject)
     g_free(self->priv->device_mutex);
 
     /* Chain up to the parent class */
-    return G_OBJECT_CLASS(cdemu_device_parent_class)->finalize(gobject);
+    G_OBJECT_CLASS(cdemu_device_parent_class)->finalize(gobject);
 }
 
 static void cdemu_device_class_init (CdemuDeviceClass *klass)
